function [] = checkInternet( websiteName )
%CHECKINTERNET - Checks whether MATLAB has intern access.
%
%   Syntax:
%       CHECKINTERNET(websiteName)
%
%   Description:
%       CHECKINTERNET(websiteName) - Tries to resolve the website specified
%       by 'websiteName'. If this succeeds, nothing happens. If this fails,
%       and error is thrown.
%    
%   Inputs:
%       websiteName - string specifying the name (incl. TLD) of a valid
%                     website.
%
%   Outputs:
%       none
%
%   Other m-files required: none
%   Subfunctions: none
%   MAT-files required: none

%   Author: Camiel Beckers
%   email: c.j.j.beckers@tue.nl
%   Website: https://research.tue.nl/en/persons/camiel-jj-beckers
%   Date: 22-Oct-2020; Last revision: 22-Oct-2020
%
%   Copyright (c) 2020, C.J.J.Beckers
%   All rights reserved.

try
    java.net.InetAddress.getByName(websiteName);
catch
    warning(['It appears that you do not have an active internet connection (or at least cannot reach ' websiteName ').' newline 'An active internet connection is required to download map and weather data.']);
end
