function fr = getVariableFr( v ,veh)
%Friction_Coefficient - Gives the friction coefficient of the Voltia eVan
% as function of the velocity of the vehcile
%
%   Syntax:
%       Fr = Friction_Coefficient(v)
%
%   Description:
%       Friction_Coefficient() - Returns the friction coefficient of the
%       Voltia eVan. This functions checks the velocity and determines if
%       this velocity corresponds to a highway, national road or village.
%    
%   Inputs:
%       v - array of doubles indicating the vehicle velocity in [m/s]
%
%   Outputs:
%       fr - Friction coefficient [-] correcponding to the velocities
%       specified by v
%
%   Other m-files required: none
%   Subfunctions: none
%   MAT-files required: none
%
%   See also: -

%   Author: Tim Geraedts
%   email: t.a.g.h.geraedts@student.tue.nl
%   Date: 10-April-2019; Last revision: 10-April-2019
%
%   Copyright (c) 2020, T.A.G.H.Geraedts
%   All rights reserved.

%% Friction coefficients for the different roads
fr_high = veh.fr_low;   % Friction coefficient on highway
fr_N    = veh.fr_mid;   % Friction coefficient on National road
fr_vil  = veh.fr_high;    % Friction coefficient on village road


v_high = veh.fr_vel2/3.6; % [m/s]  This is the velocity after it is assumed that the
                     %  vehicle is driving on a highway
v_N = veh.fr_vel1/3.6;    % [m/s]  This is the velocity after it is assumed that the
                     %  vehicle is driving on a National road or medium
                     %  asphalt
                     % Velocities lower than v_N are assumed to be on
                     % bad asphalt

%% Assign fr-value based on vehicle velocity
fr = zeros(size(v));

fr(v<v_N             ) = fr_vil;
fr(v>=v_N & v<v_high) = fr_N;
fr(v>=v_high         ) = fr_high;

end
