function par = parameters_environment( FileName )
%PARAMETERS_ENVIRONMENT - Loads environmental parameters from an Excel file
%into a struct.
%
%   Syntax:
%       par = PARAMETERS_ENVIRONMENT( FileName )
%
%   Description:
%       PARAMETERS_ENVIRONMENT() - returns a struct 'par' containing
%       several enverironment specific parameters. All parameters are in SI
%       units and are specific to the vehicle described in the excelfile
%       specified by FileName.
%    
%   Inputs:
%       FileName - The filename of an .xls-file containing the specific
%       numeric values to the environmental parameters.
%
%   Outputs:
%       par - a struct containing several constant values
%
%   Other m-files required: none
%   Subfunctions: none
%   MAT-files required: none
%
%   See also: struct, xlsread

%   Author: Camiel Beckers
%   email: c.j.j.beckers@tue.nl
%   Website: https://research.tue.nl/en/persons/camiel-jj-beckers
%   Date: 18-Jul-2019; Last revision: 31-Aug-2020
%
%   Copyright (c) 2020, C.J.J.Beckers
%   All rights reserved.

%Load data from Excel file
Excel = xlsread(FileName,'Sheet1','','basic');

par.g   = Excel(2); %[m/s^2]  Gravitational acceleration
par.rho = Excel(3); %[kg/m^3] Air density

par.windfactor = Excel(4); %[-] factor that is multiplied with the windvelocity
                           %value should typcially be smaller than zero, as
                           %to no include the full windvelocity in the
                           %calculations.

end%function